@echo off

rem Tool            wsl_drive
rem Author          Carlo Hogeveen
rem Website         eCarlo.nl/tse
rem Compatibility   WSL v2
rem Version         v1   17 Mar 2024
rem
rem If you manually connect a drive letter to a WSL distro,
rem then it loses connection after a short moment.
rem
rem This script connects a drive letter to a WSL v2 distro,
rem and then keeps running to keep the connection alive.
rem
rem Running the script again closes the connection and stops both scripts.
rem
rem Typical use:
rem   Run the script minimized from a Windows desktop shortcut.
rem   Add a free drive letter and an installed WSL distro after the script name.
rem   You can have multiple shortcuts for multiple drive letters and WSL distros
rem   and run them concurrently.
rem   Examples:
rem     wsl_drive N Debian
rem     wsl_drive U Ubuntu
rem     wsl_drive V Ubuntu-22.04
rem
rem Default use:
rem   If you do not supply parameters, then the two default configuration
rem   settings the top of this script are used.
rem   Examples:
rem     set wsl_drive=N
rem     set wsl_distro=Debian
rem
rem     set wsl_drive=U
rem     set wsl_distro=Ubuntu
rem
rem     set wsl_drive=V
rem     set wsl_distro=Ubuntu-22.04

rem ========================================
rem Start of default configuration settings:

set wsl_drive=U
set wsl_distro=Ubuntu

rem End of default configuration settings.
rem ========================================

if not "%1" == "" set wsl_drive=%1
if not "%2" == "" set wsl_distro=%2

title %wsl_drive% drive for %wsl_distro% WSL distro

echo.
if exist %wsl_drive%:\* goto drive_stop

echo Connecting %wsl_drive%: drive ...
subst %wsl_drive%: \\wsl$\%wsl_distro%\
if exist %wsl_drive%:\* goto drive_connected

echo Failed to connect U drive.
goto the_end

:drive_connected
echo %wsl_drive%: drive is connected.
ping 127.0.0.1 > nul
echo.

set /a NumberOfMessages=0
:keep_drive_alive
set /a NumberOfMessages=%NumberOfMessages%+1
echo Keeping %wsl_drive%: drive alive ... (%NumberOfMessages%)
ping -n 10 127.0.0.1 > nul
if exist %wsl_drive%: goto keep_drive_alive

:drive_stop
echo Disconnecting %wsl_drive%: drive ...
ping 127.0.0.1 > nul
subst %wsl_drive%: /D
echo %wsl_drive%: drive disconnected.

:the_end
ping 127.0.0.1 > nul
exit

